@@ -1,11 +1,18 @@
 from wordle import dictionary, randomanswer
 
+
 class Wordle:
     """Main Wordle game taking optional arguments of the answer and whether to check against the dictionary.
         random_daily changes answer every day (see github/preritdas/wordle)."""
-    def __init__(self, word: str = 'hello', real_words: bool = True, random_daily: bool = False):
+    def __init__(
+        self, word: str = 'hello', 
+        enforce_len: bool = True, 
+        real_words: bool = True, 
+        random_daily: bool = False
+    ):
         self.word = word.upper()
         self.real_words = real_words
+        self.enforce_len = enforce_len
         if random_daily == True:
             self.word = randomanswer.random_answer(daily=True).upper()
 
@@ -16,7 +23,7 @@ class Wordle:
         """Run the game. Depends on bool real_words from instantiation."""
 
         # Answer viability test
-        if len(self.word) != 5:
+        if self.enforce_len and len(self.word) != 5:
             raise Exception("The answer has to be a five-letter word.")
         if self.real_words == True and self.word.lower() not in dictionary.words:
             raise Exception(
@@ -57,11 +64,13 @@ class Wordle:
                 guess = str(input(f"Attempt {i + 1} >>> ")).upper()
 
                 # Correct failed dictionary test if real word is guessed
-                if guess.lower() in dictionary.words:
+                if self.real_words and guess.lower() in dictionary.words:
                     failed_dictionary_test = False
 
             # prepare response list
-            response = ['', '', '', '', '']
+            response = []
+            for _ in range(len(self.word_dup)):
+                response.append('')
 
             # first correctness check
             for j in range(len(guess)):
@@ -114,6 +123,7 @@ class Wordle:
         # For duplicate checking
         self.word_dup = list(self.word)
         failed_dictionary_test = False # by default
+        guess = guess.upper() # for the logic
 
         # Cheating checks
 
@@ -121,30 +131,30 @@ class Wordle:
         if self.real_words == True and guess.lower() not in dictionary.words:
             failed_dictionary_test = True
 
-        while (
-            failed_dictionary_test == True
-            or " " in guess
-            or len(guess) > len(self.word)
-        ):
-            if " " in guess:
-                return "You can't have multiple words in your guess."
-            elif len(guess) > len(self.word):
-                return f"You can't guess a word with more than {len(list(self.word))} letters."
-            elif failed_dictionary_test == True: # Not a real word
-                return "That's not a real word."
+        if " " in guess:
+            return "You can't have multiple words in your guess."
+        elif self.enforce_len and len(guess) > len(self.word):
+            return f"You can't guess a word with more than {len(list(self.word))} letters."
+        elif failed_dictionary_test == True: # Not a real word
+            return "That's not a real word."
 
-            # Correct failed dictionary test if real word is guessed
-            if guess.lower() in dictionary.words:
-                failed_dictionary_test = False
+        # Correct failed dictionary test if real word is guessed
+        if self.real_words and guess.lower() in dictionary.words:
+            failed_dictionary_test = False
 
         # prepare response list
-        response = ['', '', '', '', '']
+        response = ['' for _ in range(len(guess))]
 
         # first correctness check
         for j in range(len(guess)):
-            if guess[j] in self.word_dup and guess[j] == self.word[j]:
-                response[j] = f"*{guess[j]}*   "
-                self.word_dup.remove(guess[j])  # Duplicates
+            # out of range issue
+            try:
+                if guess[j] == self.word[j]:
+                    response[j] = f"*{guess[j]}*   "
+                    self.word_dup.remove(guess[j])
+                    continue
+            except IndexError:
+                pass
 
         # next present and absent check
         for j in range(len(guess)):
@@ -184,4 +194,4 @@ class Wordle:
     # Reset individual guesses
     def reset_guesses(self):
         """Removes all guesses from guess logging to allow 6 more attempts."""
-        self.individual_guesses = []
\ No newline at end of file
+        self.individual_guesses = []
